@@ -32,7 +32,7 @@ class ftpUtil:
             prj="P"+prj_id.zfill(6)
             stud=stud_id.zfill(11)
             no=no_file.zfill(2)
-            remote_file=prj+"_" + stud +"_" + no+"."+file_type
+            remote_file=prj+"_" + stud +"_" + no +file_type
             sftp.put(local_path,remote_file)
             print('上传成功......')
             sftp.close()
